/*
%Copyright   (c) Polak IT
%Author      SHUR
%Purpose     Create AutoPark Groups
%Codepage    1251
%Modified    21.11.2013 13:13:15 Shur
*/


// MessageBox return codes
var vbOK     = 1;
var vbCancel = 2;
var vbAbort  = 3;
var vbRetry  = 4;
var vbIgnore = 5;
var vbYes    = 6;
var vbNo     = 7;

// MessageBox style flags
var vbOKOnly           = 0x00000000;
var vbOKCancel         = 0x00000001;
var vbAbortRetryIgnore = 0x00000002;
var vbYesNoCancel      = 0x00000003;
var vbYesNo            = 0x00000004;
var vbRetryCancel      = 0x00000005;
var vbCritical         = 0x00000010;
var vbQuestion         = 0x00000020;
var vbExclamation      = 0x00000030;
var vbInformation      = 0x00000040;
var vbDefaultButton1   = 0x00000000;
var vbDefaultButton2   = 0x00000100;
var vbDefaultButton3   = 0x00000200;
var vbDefaultButton4   = 0x00000300;
var vbSystemModal      = 0x00001000;

// Group types
var ADS_GROUP_TYPE_GLOBAL_GROUP     = 0x00000002;
var ADS_GROUP_TYPE_LOCAL_GROUP      = 0x00000004; 
var ADS_GROUP_TYPE_UNIVERSAL_GROUP  = 0x00000008;
var ADS_GROUP_TYPE_SECURITY_ENABLED = 0x80000000;

// User flags
var ADS_UF_SCRIPT                                 = 0x00000001;
var ADS_UF_ACCOUNTDISABLE                         = 0x00000002;
var ADS_UF_HOMEDIR_REQUIRED                       = 0x00000008;
var ADS_UF_LOCKOUT                                = 0x00000010;
var ADS_UF_PASSWD_NOTREQD                         = 0x00000020;
var ADS_UF_PASSWD_CANT_CHANGE                     = 0x00000040;
var ADS_UF_ENCRYPTED_TEXT_PASSWORD_ALLOWED        = 0x00000080;
var ADS_UF_TEMP_DUPLICATE_ACCOUNT                 = 0x00000100;
var ADS_UF_NORMAL_ACCOUNT                         = 0x00000200;
var ADS_UF_INTERDOMAIN_TRUST_ACCOUNT              = 0x00000800;
var ADS_UF_WORKSTATION_TRUST_ACCOUNT              = 0x00001000;
var ADS_UF_SERVER_TRUST_ACCOUNT                   = 0x00002000;
var ADS_UF_DONT_EXPIRE_PASSWD                     = 0X00010000;
var ADS_UF_MNS_LOGON_ACCOUNT                      = 0X00020000;
var ADS_UF_SMARTCARD_REQUIRED                     = 0X00040000;
var ADS_UF_TRUSTED_FOR_DELEGATION                 = 0X00080000;
var ADS_UF_NOT_DELEGATED                          = 0X00100000;
var ADS_UF_USE_DES_KEY_ONLY                       = 0x00200000;
var ADS_UF_DONT_REQUIRE_PREAUTH                   = 0x00400000;
var ADS_UF_PASSWORD_EXPIRED                       = 0x00800000;
var ADS_UF_TRUSTED_TO_AUTHENTICATE_FOR_DELEGATION = 0x01000000;


function getDomainRDN(sDomainFQDN)
{
 var sDomainRDN = "";
 var rsDomainFQDN = new Array();
 rsDomainFQDN = sDomainFQDN.split(".");
 for ( var i = 0; i < rsDomainFQDN.length; i++ ){
  if ( sDomainRDN.length != 0 ){
   sDomainRDN += ",";
  }// if ...
  sDomainRDN += "dc=";
  sDomainRDN += rsDomainFQDN[i];
 }// for ...
 return sDomainRDN;
}// getDomainRDN


function objectClass(sDomain, sUserAccount)
{
 try{
  oObj = GetObject("WinNT://"+sDomain+"/"+sUserAccount);
  return oObj.Class;
 }catch(exc){
 }
 return "";
}// objectClass


function createOU(oParent, sOU)
{
 var oOU = oParent.Create("organizationalUnit", "OU="+sOU);
 oOU.SetInfo();
}// createOU


function getOrCreateOU(oParent, sOU, sOURDN)
{
 var oOU;
 try{
  oOU = GetObject(sOURDN);
  //WScript.Echo("OU  : \""+sOURDN+"\"");
 }catch(exc){
  createOU(oParent, sOU);
  oOU = GetObject(sOURDN);
 }
 return oOU;
}// getOrCreateOU


function createGroup(oParent,
                     nType,
                     sAccount,
                     sDescription)
{
 var oGroup = oAPGroupsOU.Create("group", "cn="+sAccount);
 oGroup.Put("groupType", 
            ADS_GROUP_TYPE_GLOBAL_GROUP|
            ADS_GROUP_TYPE_SECURITY_ENABLED);
 oGroup.Put("sAMAccountName", sAccount);
 if ( sDescription.length != 0 ){
  oGroup.Put("description", sDescription);
 }// if ...
 oGroup.SetInfo();
}// createGroup


function createUser(oParent,
                    nFlags,
                    sCN,
                    sAccount,
                    sUPN,
                    sDisplayName,  //  
                    sSN,           // 
                    sGivenName,    // 
                    sPassword,
                    fForceChangePassword)
{
 //Default accountExpires = TIMEQ_FOREVER
 //Default userAccountControl = ADS_UF_ACCOUNTDISABLE|
 //                             ADS_UF_PASSWD_NOTREQD|
 //                             ADS_UF_NORMAL_ACCOUNT

 var oUser = oParent.Create("user", "cn="+sCN)
 oUser.Put("sAMAccountName", sAccount);
 oUser.Put("userPrincipalName", sUPN);
 if ( sDisplayName.length != 0 ){
  oUser.Put("displayName", sDisplayName);
 }// if ...
 if ( sSN.length != 0 ){
  oUser.Put("sn", sSN);
 }// if ...
 if ( sGivenName.length != 0 ){
  oUser.Put("givenName", sGivenName);
 }// if ...
 oUser.SetInfo();
 oUser.SetPassword(sPassword);
 var nOldFlags = oUser.Get("userAccountControl");
 var nNewFlags = nOldFlags;
 nNewFlags &= ~(ADS_UF_ACCOUNTDISABLE|ADS_UF_PASSWD_NOTREQD);
 nNewFlags |= nFlags;
 if ( fForceChangePassword != 0 ){
  oUser.Put("pwdLastSet", 0);
  nNewFlags &= ~ADS_UF_DONT_EXPIRE_PASSWD;
 }// if ...
 if ( nNewFlags != nOldFlags ){
  oUser.Put("userAccountControl", nFlags);
 }// if ...
 oUser.SetInfo();
}// createUser


function addUserToGroup(sDomain, sUserAccount, sGroupAccount)
{
 var oGroup = GetObject("WinNT://"+sDomain+"/"+sGroupAccount);
 oGroup.Add("WinNT://"+sDomain+"/"+sUserAccount);
}// addUserToGroup


function addUserToGroups(sDomain, sUserAccount, sGroups)
{
 var rsGroups = new Array();
 rsGroups = sGroups.split("|");
 for ( var i = 0; i < rsGroups.length; i++ ){
  addUserToGroup(sDomain, sUserAccount, rsGroups[i]);
 }// for ...
}// addUserToGroups


function addUserToGroupLoc(sDomain, sUserAccount, sGroupAccountRus, sGroupAccountEng)
{
 var oGroup;
 try{
  oGroup = GetObject("WinNT://"+sDomain+"/"+sGroupAccountRus);
 }catch(exc){
  oGroup = GetObject("WinNT://"+sDomain+"/"+sGroupAccountEng);
 }
 oGroup.Add("WinNT://"+sDomain+"/"+sUserAccount);
}// addUserToGroupLoc




var sDomain = "";
if ( WScript.Arguments.length > 0 ){
 sDomain = WScript.Arguments(0);
}else{
 WScript.Echo("   ");
 WScript.Quit();
}// if ...

var sDomainRDN = getDomainRDN(sDomain);
var oDomain;
try{
 var oDomain = GetObject("LDAP://"+sDomainRDN);
}catch(exc){
 WScript.Echo("   \""+sDomain+"\"");
 WScript.Quit();
}

var sPolakClass = objectClass(sDomain, "Polak");
//WScript.Echo("PolakClass="+sPolakClass);
var fAddPolakToAutoParkGroups = 0;
if ( sPolakClass.length == 0 ){
 fAddPolakToAutoParkGroups = 1;
}else if ( sPolakClass == "User" ){
 var oShell = WScript.CreateObject("WScript.Shell");
 var nReact = oShell.Popup("  "+sDomain+"     "+
                           "Polak.\n\n"+
                           "    ?",  // strText
                           0,  // nSecondsToWait
                           "  ",  // strTitle
                           vbYesNoCancel|vbQuestion|vbDefaultButton1);
 if ( nReact == vbCancel ){
  WScript.Quit();
 }else if ( nReact == vbYes ){
  fAddPolakToAutoParkGroups = 1;
 }// if ...
}// if ...

var oAPOU = getOrCreateOU(oDomain,
                          "AutoPark",
                          "LDAP://"+"ou=AutoPark,"+sDomainRDN);
var oAPGroupsOU = getOrCreateOU(oAPOU,
                                "Groups",
                                "LDAP://"+"ou=Groups,ou=AutoPark,"+sDomainRDN);
var oAPUsersOU = getOrCreateOU(oAPOU,
                               "Users",
                               "LDAP://"+"ou=Users,ou=AutoPark,"+sDomainRDN);
var oAPUsersAsuOU = getOrCreateOU(oAPUsersOU,
                                  "ASU",
                                  "LDAP://"+"ou=ASU,ou=Users,ou=AutoPark,"+sDomainRDN);
var oAPUsersPolakOU = getOrCreateOU(oAPUsersOU,
                                    "Polak",
                                    "LDAP://"+"ou=Polak,ou=Users,ou=AutoPark,"+sDomainRDN);

var nGSG = ADS_GROUP_TYPE_GLOBAL_GROUP|ADS_GROUP_TYPE_SECURITY_ENABLED;
// Basic Groups
createGroup(oAPGroupsOU, nGSG, "AP_Admin",            " ");
createGroup(oAPGroupsOU, nGSG, "AP_DOT_Authors",      "   ");
createGroup(oAPGroupsOU, nGSG, "AP_InetHTTPAccess",   "  Web- ASB-");
createGroup(oAPGroupsOU, nGSG, "AP_InetUsers",        "  ");
createGroup(oAPGroupsOU, nGSG, "AP_HTTPAccess",       " Web- ASB-");
createGroup(oAPGroupsOU, nGSG, "AP_HTTPAdmin",        " Web- ASB-");
createGroup(oAPGroupsOU, nGSG, "AP_Support",          " ");
createGroup(oAPGroupsOU, nGSG, "AP_Users",            " ");
createGroup(oAPGroupsOU, nGSG, "AP_XLT_Authors",      "   ");
createGroup(oAPGroupsOU, nGSG, "ASBLogging",          " ,      SYSLOG.      ");
createGroup(oAPGroupsOU, nGSG, "End_User",            "   (   )");
createGroup(oAPGroupsOU, nGSG, "Eng",                 " ( ,      )");
createGroup(oAPGroupsOU, nGSG, "Programmers",         " ");

// Application Groups
createGroup(oAPGroupsOU, nGSG, "Acnt",                " (     )");
createGroup(oAPGroupsOU, nGSG, "Disp",                "  ");
createGroup(oAPGroupsOU, nGSG, "DispLine",            "  ");
createGroup(oAPGroupsOU, nGSG, "Econ",                " - ");
createGroup(oAPGroupsOU, nGSG, "Expl",                "   ( , )");
createGroup(oAPGroupsOU, nGSG, "FuelStock",           " ");
createGroup(oAPGroupsOU, nGSG, "Leaders",             " ");
createGroup(oAPGroupsOU, nGSG, "Mechanic",            "");
createGroup(oAPGroupsOU, nGSG, "MedInsp",             " ");
createGroup(oAPGroupsOU, nGSG, "Outpost",             "    (    )");
createGroup(oAPGroupsOU, nGSG, "Payroll",             "    ");
createGroup(oAPGroupsOU, nGSG, "Physician",           "");
createGroup(oAPGroupsOU, nGSG, "RoadSafety",          "   ");
createGroup(oAPGroupsOU, nGSG, "RprS_0",              " ");
createGroup(oAPGroupsOU, nGSG, "RprS_1",              "  ");
createGroup(oAPGroupsOU, nGSG, "RprS_2",              "  ");
createGroup(oAPGroupsOU, nGSG, "RprS_3",              "    ");
createGroup(oAPGroupsOU, nGSG, "RprS_4",              " (  )");
createGroup(oAPGroupsOU, nGSG, "RprS_5",              " ()    (  )");
createGroup(oAPGroupsOU, nGSG, "RprS_6",              "   (  )");
createGroup(oAPGroupsOU, nGSG, "RprS_7",              "    ");
createGroup(oAPGroupsOU, nGSG, "RWOp",                "  , ");
createGroup(oAPGroupsOU, nGSG, "CWOp",                " ");
createGroup(oAPGroupsOU, nGSG, "Secretary",           "");
createGroup(oAPGroupsOU, nGSG, "Sheet",               "");
createGroup(oAPGroupsOU, nGSG, "Staff",               "  ");
createGroup(oAPGroupsOU, nGSG, "Stock",               "");
createGroup(oAPGroupsOU, nGSG, "SupplyAgent",         "");
createGroup(oAPGroupsOU, nGSG, "TckCashier",          "   (    )");
createGroup(oAPGroupsOU, nGSG, "Tech",                "  ");
createGroup(oAPGroupsOU, nGSG, "TwoOp",               " (   )");

// Specific Application Groups
createGroup(oAPGroupsOU, nGSG, "CarEvnTracking",      "    ");
createGroup(oAPGroupsOU, nGSG, "SprtCrspSend",        "  ");

// Application Groups for View Only
createGroup(oAPGroupsOU, nGSG, "CarView",             "  :    ");
createGroup(oAPGroupsOU, nGSG, "ManView",             "  :   ,  ");
createGroup(oAPGroupsOU, nGSG, "StockView",           "  :   ");
createGroup(oAPGroupsOU, nGSG, "RprSCarView",         "  :    ");
createGroup(oAPGroupsOU, nGSG, "RprSOutCarView",      "  :    ");

var nStdUF = ADS_UF_NORMAL_ACCOUNT|ADS_UF_DONT_EXPIRE_PASSWD;

if ( sPolakClass.length == 0 ){
 createUser(oAPUsersPolakOU,            // oParent
            nStdUF,                     // nFlags
            " Polak IT",   // sCN
            "Polak",                    // sAccount
            "Polak"+"@"+sDomain,        // sUPN
            " Polak IT",           // sDisplayName
            "",                         // sSN
            "",                         // sGivenName
            "654321",                   // sPassword
            0);                         // fForceChangePassword
 addUserToGroupLoc(sDomain, "Polak", "", "Administrators");
 addUserToGroupLoc(sDomain, "Polak", " ", "Domain Admins");
 addUserToGroupLoc(sDomain, "Polak", " ", "Enterprise Admins");
 addUserToGroupLoc(sDomain, "Polak", " ", "Schema Admins");
 addUserToGroupLoc(sDomain, "Polak", "-  ", "Group Policy Creators Owners");
 addUserToGroupLoc(sDomain, "Polak", "   ", "Remote Desktop Users");
}// if ...
if ( fAddPolakToAutoParkGroups ){
 addUserToGroups(sDomain, "Polak", "AP_DOT_Authors|AP_HTTPAccess|AP_HTTPAdmin|AP_Users|AP_XLT_Authors");
 addUserToGroups(sDomain, "Polak", "AP_Admin|Programmers|AP_Support");
 addUserToGroups(sDomain, "Polak", "AP_InetHTTPAccess|AP_InetUsers");
}// if ...

createUser(oAPUsersAsuOU,              // oParent
           nStdUF,                     // nFlags
           "  ",  // sCN
           "AP_Guard",                 // sAccount
           "AP_Guard"+"@"+sDomain,     // sUPN
           " ",      // sDisplayName
           "",                         // sSN
           "",                         // sGivenName
           "654321",                   // sPassword
           0);                         // fForceChangePassword
addUserToGroups(sDomain, "AP_Guard", "AP_HTTPAccess|AP_Users");

//createUser(oAPUsersAsuOU,              // oParent
//           nStdUF,                     // nFlags
//           " ",      // sCN
//           "EU1",                      // sAccount
//           "EU1"+"@"+sDomain,          // sUPN
//           " ",      // sDisplayName
//           "",                         // sSN
//           "",                         // sGivenName
//           "",                         // sPassword
//           0);                         // fForceChangePassword
//addUserToGroups(sDomain, "EU1", "AP_HTTPAccess|AP_Users|End_User");

WScript.Echo("    ");
